@@ -7,13 +7,15 @@ class AtlantisClient:
 
     :param str atlantis_url: Endereço da API do serviço Atlantis
     :param str client_id: ID do cliente cadastrado no Atlantis
+    :param str client_secret: Secret do cliente cadastrado no Atlantis
     """
 
-    def __init__(self, atlantis_url, client_id):
+    def __init__(self, atlantis_url, client_id, client_secret):
         self.atlantis_url = atlantis_url
         self.client_id = client_id
+        self.client_secret = client_secret
 
-    def issue_token(self, code, client_secret):
+    def issue_token(self, code):
         """Realiza a troca do code pelo token
 
         Exemplo:
@@ -22,22 +24,20 @@ class AtlantisClient:
 
             from stl_sdk.torpedo import AtlantisClient
 
-            client = AtlantisClient('https://accounts.spacetimeanalytics.com', 'client_id_abc123')
-            token = client.issue_token('code123abc', 'id123abc')
+            client = AtlantisClient('https://accounts.spacetimeanalytics.com', 'client_id_abc123', 'client_secret_123abc')
+            token = client.issue_token('code123abc')
 
         :param code: Código concedido pelo Atlantis via redirect (authorization_code)
         :type code: str
-        :param client_secret: Secret do cliente cadastrado no Atlantis
-        :type client_secret: str
         :return: Dicionário com os tokens: ``access_token``, ``id_token`` e ``refresh_token``
         :rtype: dict
         """
         response = requests.post(
-            '{}/token'.format(self.atlantis_url),
+            '{}/api/token'.format(self.atlantis_url),
             data={
                 'code': code,
                 'client_id': self.client_id,
-                'client_secret': client_secret
+                'client_secret': self.client_secret
             },
             params={
                 'grant_type': 'authorization_code'
@@ -51,7 +51,7 @@ class AtlantisClient:
         :return: Chave pública
         :rtype: str
         """
-        response = requests.get('{}/key'.format(self.atlantis_url))
+        response = requests.get('{}/api/key'.format(self.atlantis_url))
         response.raise_for_status()
         return response.json()
 
